import { WebGPUObjectError } from '../utils/errors.js'

/** @import { BindGroupEntry } from '../core/graphics-device.js' */

export class Sampler {
  _device
  _handle

  get handle() {
    return this._handle
  }

  get label() {
    return this._handle.label
  }

  /**
   * @param {GPUDevice} device
   * @param {GPUSampler} sampler
   */
  constructor(device, sampler) {
    this._device = device
    this._handle = sampler
  }

  /**
   * @param {GPUDevice} device
   * @param {GPUSamplerDescriptor} descriptor
   */
  static create(device, descriptor) {
    try {
      return new Sampler(
        device,
        device.createSampler(descriptor)
      )
    } catch (err) {
      throw WebGPUObjectError.from(err, Sampler)
    }
  }

  /**
   * @param {BindGroupEntry} _entry 
   */
  asBindingResource(_entry) {
    return this._handle
  }
}

